from enum import Enum
from datetime import datetime, timezone

from canary.const import RECORDING_STATES, DATETIME_FORMAT


class Customer:
    def __init__(self, data):
        self._id = data["id"]
        self._first_name = data["first_name"]
        self._last_name = data["last_name"]
        self._is_celsius = data["celsius"]

    @property
    def customer_id(self):
        return self._id

    @property
    def first_name(self):
        return self._first_name

    @property
    def last_name(self):
        return self._last_name

    @property
    def is_celsius(self):
        return self._is_celsius


class Location:
    def __init__(self, data, modes_by_name):
        self._id = data["id"]
        self._name = data["name"]
        self._is_private = data["is_private"]
        self._devices = []
        self._customers = []

        mode_name = data.get("mode", {}).get("name", None)
        self._mode = modes_by_name.get(mode_name, None)

        current_mode_name = data.get("current_mode", {}).get("name", None)
        self._current_mode = modes_by_name.get(current_mode_name, None)

        for device_data in data["devices"]:
            self._devices.append(Device(device_data))

        for customer_data in data["customers"]:
            self._customers.append(Customer(customer_data))

    @property
    def location_id(self):
        return self._id

    @property
    def name(self):
        return self._name

    @property
    def mode(self):
        return self._mode

    @property
    def current_mode(self):
        return self._current_mode

    @property
    def devices(self):
        return self._devices

    @property
    def customers(self):
        return self._customers

    @property
    def is_private(self):
        return self._is_private

    @property
    def is_recording(self):
        if self.current_mode is None:
            return False

        return self.current_mode.name in RECORDING_STATES

    @property
    def is_celsius(self):
        for customer in self._customers:
            if customer is not None and customer.is_celsius:
                return True

        return False


class Device:
    def __init__(self, data):
        self._id = data["id"]
        self._uuid = data["uuid"]
        self._name = data["name"]
        self._device_mode = None
        self._is_online = data["online"]
        self._device_type = data["device_type"]

    @property
    def device_id(self):
        return self._id

    @property
    def uuid(self):
        return self._uuid

    @property
    def name(self):
        return self._name

    @property
    def device_mode(self):
        return self._device_mode

    @property
    def is_online(self):
        return self._is_online

    @property
    def device_type(self):
        return self._device_type


class Reading:
    def __init__(self, data):
        self._sensor_type = SensorType(data["sensor_type"]["name"])
        self._value = data["value"]

    @property
    def sensor_type(self):
        return self._sensor_type

    @property
    def value(self):
        return self._value


class SensorType(Enum):
    AIR_QUALITY = "air_quality"
    HUMIDITY = "humidity"
    TEMPERATURE = "temperature"
    BATTERY = "battery"
    WIFI = "wifi"
    DATE_LAST_ENTRY = "last_entry_date"
    ENTRIES_CAPTURED_TODAY = "entries_captured_today"


class Entry:
    def __init__(self, data):
        self._entry_id = data["id"]
        self._start_time = data.get("start_time", "")
        self._device_uuids = []
        self._starred = data.get("starred", False)
        self._selected = data.get("selected", False)
        self._thumbnails = []

        for device_data in data.get("device_uuids", []):
            # for whatever reason, this call has hyphens in the uuid's
            # while all others do not
            self._device_uuids.append(device_data.replace("-", ""))

        for thumbnail_data in data.get("thumbnails", []):
            self._thumbnails.append(Thumbnail(thumbnail_data))

    @property
    def entry_id(self):
        return self._entry_id

    @property
    def start_time(self):  # -> datetime | None:
        try:
            return datetime.strptime(self._start_time + "Z", DATETIME_FORMAT).replace(
                tzinfo=timezone.utc
            )
        except ValueError:
            return None

    @property
    def device_uuids(self):
        return self._device_uuids

    @property
    def starred(self):
        return self._starred

    @property
    def selected(self):
        return self._selected

    @property
    def thumbnails(self):
        return self._thumbnails


class Thumbnail:
    def __init__(self, data):
        self._image_url = data["signed_url"]

    @property
    def image_url(self):
        return self._image_url


class Mode:
    def __init__(self, data):
        self._id = data["id"]
        self._name = data["name"]
        self._resource_uri = data["resource_uri"]

    def __repr__(self):
        return f"Mode(id={self.mode_id}, name={self.name})"

    @property
    def mode_id(self):
        return self._id

    @property
    def name(self):
        return self._name

    @property
    def resource_uri(self):
        return self._resource_uri



"""The tests for the Canary sensor platform."""
import os
import unittest

import pytest
import requests_mock

from canary.api import Api
from canary.const import (
    URL_LOGIN_API,
    URL_MODES_API,
    URL_LOCATIONS_API,
    URL_READINGS_API,
    URL_LOGIN_PAGE,
    COOKIE_XSRF_TOKEN,
    COOKIE_SSESYRANAC,
)
from canary.model import SensorType

COOKIE_XSRF_VAL = "xsrf"
COOKIE_COOKIE_SSESYRANAC_VAL = "ssesyranac"

FIXED_DATE_RANGE = (
    "?end=2022-05-05T23%3A59%3A59.999Z&start=2022-05-05T00%3A00%3A00.000Z"
)
URL_ENTRY_API = f"https://my.canary.is/api/entries/tl2/70001{FIXED_DATE_RANGE}"


def load_fixture(filename):
    """Load a fixture."""
    path = os.path.join(os.path.dirname(__file__), "fixtures", filename)
    with open(path) as fptr:
        return fptr.read()


def _setup_responses(mock):
    mock.register_uri("POST", URL_LOGIN_API, text=load_fixture("api_login.json"))

    mock.register_uri("GET", URL_MODES_API, text=load_fixture("api_modes.json"))

    mock.register_uri("GET", URL_LOCATIONS_API, text=load_fixture("api_locations.json"))

    mock.register_uri(
        "GET", URL_READINGS_API, text=load_fixture("api_readings_80005.json")
    )

    mock.register_uri(
        "GET",
        URL_LOGIN_PAGE,
        cookies={
            COOKIE_XSRF_TOKEN: COOKIE_XSRF_VAL,
            COOKIE_SSESYRANAC: COOKIE_COOKIE_SSESYRANAC_VAL,
        },
    )

    mock.register_uri(
        "GET",
        URL_ENTRY_API,
        text=load_fixture("api_entries_70001.json"),
    )


class TestApi(unittest.TestCase):
    @requests_mock.Mocker()
    def test_locations(self, mock):
        """Test the Canary locations API."""
        _setup_responses(mock)
        api = Api("user", "pass")

        locations = api.get_locations()
        self.assertEqual(2, len(locations))

        for location in locations:
            if location.name == "Vacation Home":
                self.assertTrue(location.is_recording)
                self.assertFalse(location.is_private)
                self.assertTrue(location.is_celsius)
                self.assertEqual(2, len(location.customers))
                self.assertEqual("away", location.mode.name)
                self.assertEqual("armed", location.current_mode.name)
                self.assertEqual(70001, location.location_id)
            elif location.name == "Home":
                self.assertFalse(location.is_recording)
                self.assertFalse(location.is_private)
                self.assertFalse(location.is_celsius)
                self.assertEqual(1, len(location.customers))
                self.assertEqual("home", location.mode.name)
                self.assertEqual("standby", location.current_mode.name)
                self.assertEqual(70002, location.location_id)

    @pytest.mark.freeze_time("2022-05-05")
    @requests_mock.Mocker()
    def test_location_with_motion_entry(self, mock):
        """Test the Canary entries API."""
        _setup_responses(mock)
        api = Api("user", "pass")

        entries = api.get_entries(70001)
        self.assertEqual(2, len(entries))

        entry = entries[0]
        self.assertEqual("00000000-0000-0000-0001-000000000000", entry.entry_id)
        self.assertEqual("2022-05-06 00:08:14+00:00", str(entry.start_time))
        self.assertEqual(False, entry.starred)
        self.assertEqual(False, entry.selected)
        self.assertEqual(1, len(entry.thumbnails))
        self.assertEqual(1, len(entry.device_uuids))

        thumbnail = entry.thumbnails[0]
        self.assertEqual("https://image_url.com", thumbnail.image_url)

        device_uuid = entry.device_uuids[0]
        self.assertEqual("fffffffffeedffffffffffffffffffff", device_uuid)

    @requests_mock.Mocker()
    def test_device_with_readings(self, mock):
        """Test the Canary entries API."""
        _setup_responses(mock)
        api = Api("user", "pass")

        readings = api.get_readings(80001)
        self.assertEqual(6, len(readings))

        readings = api.get_latest_readings(80001)
        self.assertEqual(3, len(readings))

        for reading in readings:
            if reading.sensor_type == SensorType.AIR_QUALITY:
                self.assertEqual("0.8129177689552307", reading.value)
            elif reading.sensor_type == SensorType.HUMIDITY:
                self.assertEqual("41.68813060192352", reading.value)
            elif reading.sensor_type == SensorType.TEMPERATURE:
                self.assertEqual("19.0007521446715", reading.value)



"""The tests for the Canary sensor platform."""
import os
import unittest

import requests_mock

from canary.live_stream_api import LiveStreamApi
from canary.const import (
    URL_LOGIN_API,
    URL_LOGIN_PAGE,
    COOKIE_XSRF_TOKEN,
    COOKIE_SSESYRANAC,
)

COOKIE_XSRF_VAL = "xsrf"
COOKIE_COOKIE_SSESYRANAC_VAL = "ssesyranac"


def load_fixture(filename):
    """Load a fixture."""
    path = os.path.join(os.path.dirname(__file__), "fixtures", filename)
    with open(path) as fptr:
        return fptr.read()


def _setup_responses(mock):
    mock.register_uri(
        "POST", URL_LOGIN_API, text=load_fixture("live_stream_api_login.json")
    )
    mock.register_uri(
        "GET",
        URL_LOGIN_PAGE,
        cookies={
            COOKIE_XSRF_TOKEN: COOKIE_XSRF_VAL,
            COOKIE_SSESYRANAC: COOKIE_COOKIE_SSESYRANAC_VAL,
        },
    )


class TestLiveStreamApi(unittest.TestCase):
    @requests_mock.Mocker()
    def test_login(self, mock):
        """Test login for canary live stream api"""
        _setup_responses(mock)
        api = LiveStreamApi("user", "pass")

        api.login()

        with self.subTest("stores the token on the api object"):
            self.assertEqual(api._token, "ffffffffffffffffffffffffffffffffffffffff")

        with self.subTest("stores ssesyranac cookie on the api object"):
            self.assertEqual(api._ssesyranac, "ssesyranac")



import logging

import requests
from requests import HTTPError

from canary.const import (
    URL_LOGIN_PAGE,
    COOKIE_XSRF_TOKEN,
    COOKIE_SSESYRANAC,
    URL_LOGIN_API,
    ATTR_USERNAME,
    ATTR_PASSWORD,
    ATTR_CLIENT_ID,
    ATTR_VALUE_CLIENT_ID,
    ATTR_VALUE_GRANT_TYPE,
    ATTR_GRANT_TYPE,
    ATTR_SCOPE,
    ATTR_VALUE_SCOPE,
    ATTR_TOKEN,
    URL_WATCHLIVE_BASE,
    ATTR_SESSION_ID,
    URL_ENTRIES_API,
    HEADER_XSRF_TOKEN,
    HEADER_AUTHORIZATION,
    HEADER_VALUE_AUTHORIZATION,
    ATTR_DEVICE_UUID,
)
from canary.model import Entry

_LOGGER = logging.getLogger(__name__)


class LiveStreamApi:
    def __init__(self, username, password, timeout=10, token=None):
        self._username = username
        self._password = password
        self._timeout = timeout
        self._token = token
        self._ssesyranac = None
        self._xsrf_token = None

        self.pre_login()
        if token is None:
            self.login()

    def pre_login(self):
        response = requests.get(URL_LOGIN_PAGE)

        xsrf_token = response.cookies[COOKIE_XSRF_TOKEN]
        ssesyranac = response.cookies[COOKIE_SSESYRANAC]

        self._ssesyranac = ssesyranac
        self._xsrf_token = xsrf_token

    def login(self):
        response = self._call_api(
            "post",
            URL_LOGIN_API,
            params={
                ATTR_USERNAME: self._username,
                ATTR_PASSWORD: self._password,
                ATTR_CLIENT_ID: ATTR_VALUE_CLIENT_ID,
                ATTR_GRANT_TYPE: ATTR_VALUE_GRANT_TYPE,
                ATTR_SCOPE: ATTR_VALUE_SCOPE,
            },
        )

        _LOGGER.debug(
            "Received API response: %d, %s", response.status_code, response.content
        )

        response.raise_for_status()

        self._token = response.json()[ATTR_TOKEN]

    def start_session(self, device_uuid):
        response = self._call_api(
            "post",
            f"{URL_WATCHLIVE_BASE}{device_uuid}/session",
            json={},  # "deviceUUID": device_uuid},
        )
        response.raise_for_status()

        session_id = response.json().get(ATTR_SESSION_ID)

        if self.renew_session(device_uuid, session_id):
            return session_id

        return None

    def renew_session(self, device_uuid, session_id):
        response = self._call_api(
            "post",
            f"{URL_WATCHLIVE_BASE}{device_uuid}/send",
            json={ATTR_SESSION_ID: session_id},
        )
        response.raise_for_status()

        json = response.json()

        return "message" in json and json["message"] == "success"

    def stop_session(self, device_uuid, session_id):
        """Ends the session"""
        response = self._call_api(
            "post",
            f"{URL_WATCHLIVE_BASE}{device_uuid}/stop",
            json={
                ATTR_DEVICE_UUID: device_uuid,
                ATTR_SESSION_ID: session_id,
                "action": "delete",
            },
        )
        response.raise_for_status()

        json = response.json()

        return "message" in json and json["message"] == "success"

    def get_entries(self, location_id, params):
        json = self._call_api(
            "get", f"{URL_ENTRIES_API}{location_id}", params=params
        ).json()

        return [Entry(data) for data in json]

    def get_live_stream_url(self, device_id, session_id):
        return f"{URL_WATCHLIVE_BASE}{device_id}/{session_id}/stream.m3u8"

    def _call_api(self, method, url, params=None, **kwargs):
        _LOGGER.debug("About to call %s with %s", url, params)

        response = requests.request(
            method,
            url,
            params=params,
            timeout=self._timeout,
            headers=self._api_headers(),
            cookies=self._api_cookies(),
            **kwargs,
        )

        _LOGGER.debug(
            "Received API response: %d, %s", response.status_code, response.content
        )

        response.raise_for_status()

        return response

    def _api_cookies(self):
        return {
            COOKIE_XSRF_TOKEN: self._xsrf_token,
            COOKIE_SSESYRANAC: self._ssesyranac,
        }

    def _api_headers(self):
        return {
            HEADER_XSRF_TOKEN: self._xsrf_token,
            HEADER_AUTHORIZATION: f"{HEADER_VALUE_AUTHORIZATION} {self._token}",
        }

    @property
    def auth_token(self):  # -> str | None:
        return self._token


class LiveStreamSession:
    def __init__(self, api, device):
        self._api = api
        self._device_uuid = device.uuid
        self._device_id = device.device_id
        self._session_id = None

        self.start_renew_session()

    def start_renew_session(self):
        if self._session_id is None:
            self._session_id = self._api.start_session(self._device_uuid)
        else:
            try:
                self._api.renew_session(self._device_uuid, self._session_id)
            except HTTPError as ex:
                if ex.response.status_code == 403:
                    self._session_id = self._api.start_session(self._device_uuid)
                else:
                    self._session_id = None
                    raise ex

    def stop_session(self) -> None:
        self._api.stop_session(self._device_uuid, self._session_id)
        self.clear_session()

    def clear_session(self) -> None:
        self._session_id = None

    @property
    def live_stream_url(self):  # -> str | None:
        if self._session_id is None:
            return None
        return self._api.get_live_stream_url(self._device_id, self._session_id)

    @property
    def auth_token(self):  # -> str | None:
        if self._api is None:
            return None
        return self._api.auth_token



import logging
from datetime import datetime, timedelta, date

import requests

from canary.const import (
    URL_LOGIN_API,
    ATTR_USERNAME,
    ATTR_PASSWORD,
    ATTR_CLIENT_ID,
    ATTR_VALUE_CLIENT_ID,
    ATTR_VALUE_CLIENT_SECRET,
    ATTR_CLIENT_SECRET,
    ATTR_GRANT_TYPE,
    ATTR_VALUE_SCOPE,
    ATTR_VALUE_GRANT_TYPE,
    ATTR_SCOPE,
    HEADER_USER_AGENT,
    HEADER_VALUE_USER_AGENT,
    ATTR_TOKEN,
    URL_MODES_API,
    ATTR_OBJECTS,
    URL_LOCATIONS_API,
    URL_LOCATION_API,
    DATETIME_FORMAT,
    URL_READINGS_API,
    HEADER_AUTHORIZATION,
    HEADER_VALUE_AUTHORIZATION,
    DATETIME_MS_FORMAT,
    DATETIME_MS_FORMAT_NOTZ,
)
from canary.live_stream_api import LiveStreamApi, LiveStreamSession
from canary.model import Mode, Location, Reading

_LOGGER = logging.getLogger(__name__)


class Api:
    def __init__(self, username, password, timeout=10, token=None):
        self._username = username
        self._password = password
        self._timeout = timeout
        self._token = token
        self._modes_by_name = {}
        self._live_stream_api = None

        if self._token is None:
            self.login()
        else:
            self._modes_by_name = {mode.name: mode for mode in self.get_modes()}

    def login(self):
        response = requests.post(
            URL_LOGIN_API,
            {
                ATTR_USERNAME: self._username,
                ATTR_PASSWORD: self._password,
                ATTR_CLIENT_ID: ATTR_VALUE_CLIENT_ID,
                ATTR_CLIENT_SECRET: ATTR_VALUE_CLIENT_SECRET,
                ATTR_GRANT_TYPE: ATTR_VALUE_GRANT_TYPE,
                ATTR_SCOPE: ATTR_VALUE_SCOPE,
            },
            timeout=self._timeout,
            headers={HEADER_USER_AGENT: HEADER_VALUE_USER_AGENT},
        )

        _LOGGER.debug(
            "Received login response: %d, %s", response.status_code, response.content
        )

        response.raise_for_status()

        self._token = response.json()[ATTR_TOKEN]
        self._modes_by_name = {mode.name: mode for mode in self.get_modes()}

    def get_modes(self):
        json = self._call_api("get", URL_MODES_API).json()[ATTR_OBJECTS]
        return [Mode(data) for data in json]

    def get_locations(self):
        json = self._call_api("get", URL_LOCATIONS_API).json()[ATTR_OBJECTS]
        return [Location(data, self._modes_by_name) for data in json]

    def get_location(self, location_id):
        url = f"{URL_LOCATION_API}{location_id}/"
        json = self._call_api("get", url).json()
        return Location(json, self._modes_by_name)

    def set_location_mode(self, location_id, mode_name, is_private=False):
        url = f"{URL_LOCATION_API}{location_id}/"
        self._call_api(
            "patch",
            url,
            json={
                "mode": self._modes_by_name[mode_name].resource_uri,
                "is_private": is_private,
            },
        )

    def get_readings(self, device_id):
        end = datetime.utcnow()
        start = end - timedelta(minutes=5)
        created_range = (
            f"{start.strftime(DATETIME_FORMAT)},{end.strftime(DATETIME_FORMAT)}"
        )
        json = self._call_api(
            "get",
            URL_READINGS_API,
            {
                "created__range": created_range,
                "device": device_id,
                #  "resolution": "10m",
                "limit": 0,
            },
        ).json()[ATTR_OBJECTS]
        return [Reading(data) for data in json]

    def get_latest_readings(self, device_id):
        readings = self.get_readings(device_id)
        readings_by_type = {}

        for reading in readings:
            if reading.sensor_type not in readings_by_type:
                readings_by_type[reading.sensor_type] = reading

        return readings_by_type.values()

    def get_entries(self, location_id):
        if self._live_stream_api is None:
            self._live_stream_api = LiveStreamApi(
                self._username, self._password, self._timeout, self._token
            )

        utc_beginning, utc_ending = self._get_todays_date_range_utc()

        return self._live_stream_api.get_entries(
            location_id,
            {
                "end": f"{utc_ending.strftime(DATETIME_MS_FORMAT)[:-3]}Z",
                "start": f"{utc_beginning.strftime(DATETIME_MS_FORMAT)[:-3]}Z",
            },
        )

    def get_latest_entries(self, location_id):
        entries = self.get_entries(location_id)
        entries_by_device_uuid = {}

        for entry in entries:
            for device_uuid in entry.device_uuids:
                if device_uuid not in entries_by_device_uuid:
                    entries_by_device_uuid[device_uuid] = entry

        return entries_by_device_uuid.values()

    def get_live_stream_session(self, device):
        if self._live_stream_api is None:
            self._live_stream_api = LiveStreamApi(
                self._username, self._password, self._timeout, self._token
            )
        return LiveStreamSession(self._live_stream_api, device)

    def _get_todays_date_range_utc(self):
        utc_offset = datetime.utcnow() - datetime.now()
        today = date.today()
        beginning = today.strftime("%Y-%m-%d 00:00:00.0001")
        utc_beginning = (
            datetime.strptime(beginning, DATETIME_MS_FORMAT_NOTZ) + utc_offset
        )
        ending = today.strftime("%Y-%m-%d 23:59:59.99999")
        utc_ending = datetime.strptime(ending, DATETIME_MS_FORMAT_NOTZ) + utc_offset
        return utc_beginning, utc_ending

    def _call_api(self, method, url, params=None, **kwargs):
        _LOGGER.debug("About to call %s with %s", url, params)

        response = requests.request(
            method,
            url,
            params=params,
            timeout=self._timeout,
            headers=self._api_headers(),
            **kwargs,
        )

        _LOGGER.debug(
            "Received API response: %d, %s", response.status_code, response.content
        )

        response.raise_for_status()

        return response

    def _api_headers(self):
        return {
            HEADER_USER_AGENT: HEADER_VALUE_USER_AGENT,
            HEADER_AUTHORIZATION: f"{HEADER_VALUE_AUTHORIZATION} {self._token}",
        }

    @property
    def auth_token(self):  # -> str | None:
        return self._token



HEADER_AUTHORIZATION = "Authorization"
HEADER_USER_AGENT = "User-Agent"

HEADER_VALUE_AUTHORIZATION = "Bearer"
HEADER_VALUE_USER_AGENT = "Canary/5.9.0 (iPhone; iOS 15.4.1; Scale/3.00)"

URL_LOGIN_PAGE = "https://my.canary.is/manifest.json"
URL_WATCHLIVE_BASE = "https://my.canary.is/api/watchlive/"
# URL_LOGIN_API = "https://api-prod.canaryis.com/o/access_token/"
URL_ENTRIES_API = "https://my.canary.is/api/entries/tl2/"
URL_LOGIN_API = "https://api.canaryis.com/o/access_token/"
URL_LOCATIONS_API = "https://api.canaryis.com/v1/locations/"
URL_LOCATION_API = "https://api.canaryis.com/v1/locations/"
URL_MODES_API = "https://api.canaryis.com/v1/modes/"
URL_READINGS_API = "https://api.canaryis.com/v1/readings/"

ATTR_USERNAME = "username"
ATTR_PASSWORD = "password"
ATTR_CLIENT_ID = "client_id"
ATTR_CLIENT_SECRET = "client_secret"
ATTR_GRANT_TYPE = "grant_type"
ATTR_SCOPE = "scope"
ATTR_TOKEN = "access_token"
ATTR_SESSION_ID = "sessionId"
ATTR_DEVICE_UUID = "deviceUUID"
ATTR_OBJECTS = "objects"

ATTR_VALUE_CLIENT_ID = "a183323eab0544d83808"
ATTR_VALUE_CLIENT_SECRET = "ba883a083b2d45fa7c6a6567ca7a01e473c3a269"
ATTR_VALUE_GRANT_TYPE = "password"
ATTR_VALUE_SCOPE = "write"

DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
DATETIME_FORMAT_NOTZ = "%Y-%m-%dT%H:%M:%S"
DATETIME_MS_FORMAT = "%Y-%m-%dT%H:%M:%S.%f"
DATETIME_MS_FORMAT_NOTZ = "%Y-%m-%d %H:%M:%S.%f"

LOCATION_MODE_HOME = "home"
LOCATION_MODE_AWAY = "away"
LOCATION_MODE_NIGHT = "night"

LOCATION_STATE_ARMED = "armed"
LOCATION_STATE_DISARMED = "disarmed"
LOCATION_STATE_PRIVACY = "privacy"
LOCATION_STATE_STANDBY = "standby"

RECORDING_STATES = [LOCATION_STATE_ARMED, LOCATION_STATE_DISARMED]

COOKIE_XSRF_TOKEN = "XSRF-TOKEN"
COOKIE_SSESYRANAC = "ssesyranac"

HEADER_XSRF_TOKEN = "X-XSRF-TOKEN"
